remove STL vector
[c11tester.git] / main.cc
diff --git a/main.cc b/main.cc
index a484f497458ee078270aa2cd52ccc2a20c551c1a..5396823334df9a0b47f3077f3c352cc6774e7e1b 100644 (file)
--- a/main.cc
+++ b/main.cc
@@ -171,16 +171,16 @@ int main(int argc, char **argv)
        main_argv = argv;
 
        /*
* If this printf statement is removed, CDSChecker will fail on an
         * assert on some versions of glibc.  The first time printf is
         * called, it allocated internal buffers.  We can't easily snapshot
         * libc since we also use it.
         */
 
-       printf("CDSChecker\n"
-                                "Copyright (c) 2013 Regents of the University of California. All rights reserved.\n"
+       printf("C11Tester\n"
+                                "Copyright (c) 2013 and 2019 Regents of the University of California. All rights reserved.\n"
                                 "Distributed under the GPLv2\n"
-                                "Written by Brian Norris and Brian Demsky\n\n");
+                                "Written by Weiyu Luo, Brian Norris, and Brian Demsky\n\n");
 
        /* Configure output redirection for the model-checker */
        redirect_output();
@@ -198,13 +198,9 @@ int main(int argc, char **argv)
        model_params *params = model->getParams();
        parse_options(params, main_argc, main_argv);
 
-       //Initialize race detector
-       initRaceDetector();
 
-       snapshot_stack_init();
        install_trace_analyses(model->get_execution());
 
-       snapshot_record(0);
        model->startMainThread();
        DEBUG("Exiting\n");
 }
@@ -171,16 +171,16 @@ int main(int argc, char **argv)
 
        /*
-        * If this printf statement is removed, CDSChecker will fail on an
+        * If this printf statement is removed, C11Tester will fail on an
         * assert on some versions of glibc.  The first time printf is
         * called, it allocated internal buffers.  We can't easily snapshot